/* BdfServer_API - Copyright (c) 2020-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.api.instruction;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.tools.BdfServerUtils;
import fr.exemole.bdfserver.tools.instruction.BdfErrors;
import fr.exemole.bdfserver.tools.roles.PermissionUtils;
import java.util.Locale;
import net.fichotheque.Fichotheque;
import net.fichotheque.Subset;
import net.fichotheque.extraction.ExtractionContext;
import net.fichotheque.tools.extraction.ExtractionContextBuilder;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.MessageLocalisation;


/**
 *
 * @author Vincent Calame
 */
public interface BdfParameters {

    public BdfServer getBdfServer();

    public BdfUser getBdfUser();

    public PermissionSummary getPermissionSummary();

    public default Fichotheque getFichotheque() {
        return getBdfServer().getFichotheque();
    }

    public default Lang getWorkingLang() {
        return getBdfUser().getWorkingLang();
    }

    public default Locale getFormatLocale() {
        return getBdfUser().getFormatLocale();
    }

    public default MessageLocalisation getMessageLocalisation() {
        return getBdfServer().getL10nManager().getMessageLocalisation(getBdfUser());
    }

    public default void checkFichothequeAdmin() throws PermissionException {
        if (!getBdfServer().getPermissionManager().isAdmin(getBdfUser().getRedacteur())) {
            throw BdfErrors.permission("_ error.permission.admin");
        }
    }

    public default void checkSubsetAdmin(Subset subset) throws PermissionException {
        PermissionUtils.checkSubsetAdmin(getPermissionSummary(), subset);
    }

    public default void checkSubsetAccess(Subset subset) throws PermissionException {
        PermissionUtils.checkSubsetAccess(getPermissionSummary(), subset);
    }

    public default void checkSphereSupervisor(String sphereName) throws PermissionException {
        PermissionUtils.checkSphereSupervisor(getBdfServer(), getBdfUser(), sphereName);
    }

    public default ExtractionContextBuilder getExtractionContextBuilder() {
        return BdfServerUtils.initExtractionContextBuilder(getBdfServer(), getBdfUser())
                .setSubsetAccessPredicate(getPermissionSummary().getSubsetAccessPredicate());
    }

    public default ExtractionContext getDefaultExtractionContext() {
        return getExtractionContextBuilder().toExtractionContext();
    }

}
