/* BdfServer_Html - Copyright (c) 2020-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.html.consumers;

import java.util.function.BiConsumer;
import net.mapeadores.util.html.HtmlPrinter;
import net.mapeadores.util.localisation.Litteral;


/**
 *
 * @author Vincent Calame
 */
public class SelectOption implements BiConsumer<HtmlPrinter, Object> {

    private final String value;
    private Object textL10nObject;

    public SelectOption(String value) {
        this.value = value;
    }

    public String value() {
        return value;
    }

    public SelectOption textL10nObject(Object textL10nObject) {
        this.textL10nObject = textL10nObject;
        return this;
    }

    public SelectOption text(String text) {
        if (text == null) {
            this.textL10nObject = null;
        } else {
            this.textL10nObject = new Litteral(text);
        }
        return this;
    }

    public static SelectOption init(String value) {
        return new SelectOption(value);
    }

    @Override
    public void accept(HtmlPrinter hp, Object object) {
        boolean selected = false;
        if (object != null) {
            if (object instanceof Boolean) {
                selected = (Boolean) object;
            } else {
                selected = (object.equals(value));
            }
        }
        hp
                .OPTION(value, selected);
        if (textL10nObject != null) {
            hp
                    .__localize(textL10nObject);
        }
        hp
                ._OPTION();
    }

}
