/**
 * Objet global définissant l'espace de nom Overlay
 * 
 * v 0.3.2
 * 
 * @namespace Overlay
 */
var Overlay = {};

Overlay.idNumber = 1;
Overlay.activeInfoArray = new Array();
Overlay.closeTooltip = "Close";

Overlay.Info = function (overlayId, escapeClose, otherCloseKey) {
    this.overlayId = overlayId;
    this.escapeClose = escapeClose;
    this.otherCloseKey = otherCloseKey;
};

Overlay.addEscapeKeyHandler = function (target) {
    $(target).on('keydown.overlay', function (event) {
        var lastOverlay = Overlay.getLastOverlay();
        if (lastOverlay) {
            let closeEvent = false;
            if (lastOverlay.escapeClose) {
                if (event.key === "Escape") {
                    closeEvent = true;
                }
            }
            if ((!closeEvent) && (lastOverlay.otherCloseKey)) {
                if (event.key === lastOverlay.otherCloseKey) {
                    closeEvent = true;
                }
            }
            if (closeEvent) {
                Overlay.end(lastOverlay.overlayId);
            }
        }
        
    });
};

Overlay.removeEscapeKeyHandler = function (target) {
    $(target).off('keydown.overlay');
};

Overlay.getLastOverlay = function() {
    var length = Overlay.activeInfoArray.length;
    if (length > 0) {
        return Overlay.activeInfoArray[length - 1];
    } else {
        return null;
    }
};

Overlay.start = function (settings) {
    var closeTooltip = Overlay.closeTooltip;
    if (settings.closeTooltip) {
        closeTooltip = settings.closeTooltip;
    }
    var overlayIdNumber = Overlay.idNumber;
    Overlay.idNumber++;
    var overlayId = "overlay_" + overlayIdNumber;
    var overlayInfo = new Overlay.Info(overlayId, _checkSetting("escapeClose", true));
    if (Overlay.activeInfoArray.length === 0) {
        Overlay.addEscapeKeyHandler(document);
    }
    Overlay.activeInfoArray.push(overlayInfo);
    var $overlayBlocker = $(_getDiv("blocker")).attr("data-overlay-role", "blocker").attr("tabindex", "-1");
    var $overlayDialog = $(_getDiv("dialog")).appendTo($overlayBlocker);
    $("body")
        .append($overlayBlocker)
        .css('overflow','hidden');
    var overlayBody = _getDiv("header") +  _getDiv("content") + _getDiv("footer");
    var includeForm = false;
    if (settings.formAttrs || settings.ajaxForm || settings.formSubmit) {
        includeForm = true;
        var $form = $("<form/>");
        if (settings.formAttrs) {
            for(var prop in settings.formAttrs) {
                $form.attr(prop, settings.formAttrs[prop]);
            }
        }
        if (settings.ajaxForm) {
            var initialBeforeSubmit = settings.ajaxForm.beforeSubmit;
            settings.ajaxForm.beforeSubmit = function (arr, $form, options) {
                if ((initialBeforeSubmit) && (initialBeforeSubmit(arr, $form, options) === false)) {
                    return false;
                }
                _startWaiting();
            };
            var initialSuccess = settings.ajaxForm.success;
            settings.ajaxForm.success = function (data, textStatus, jqXHR, $form) {
                _endWaiting();
                initialSuccess(data, textStatus, jqXHR, $form);
            };
            $form.ajaxForm(settings.ajaxForm);
        } else if (settings.formSubmit) {
            $form.submit(function () {
                return settings.formSubmit($(this));
            });
        }
        $overlayDialog.append($form.html(overlayBody));
        $form.data("overlayId", overlayId);
    } else {
        $overlayDialog.html(overlayBody);
    }
    _setContent("header", settings.header);
    _setContent("content", settings.content);
    _setContent("footer", settings.footer);
    var clickClose = _checkSetting("clickClose", true);
    var showClose = _checkSetting("showClose", true);
    $overlayBlocker
        .click(function() {
            if (clickClose) {
                Overlay.end(overlayId);
            }
        })
        .data("beforeEnd", settings.beforeEnd)
        .data("afterEnd", settings.afterEnd)
        .css("z-index", 10000 + overlayIdNumber);
    if (showClose) {
        $overlayDialog
            .append("<button data-overlay-role='close' class='overlay-button-Close' title='" +  closeTooltip + " (Esc)'>&times</button>")
            .on("click.overlay", "[data-overlay-role='close']", function () {
                Overlay.end(overlayId);
            });
    }
    $overlayDialog
        .click(function (event) {
            event.stopPropagation();
        });
    if (settings.isWaiting) {
        _startWaiting();
    }
    $overlayBlocker.fadeIn(function () {
        $overlayDialog.show();
        if (settings.afterStart) {
            settings.afterStart(overlayId, _endWaiting);
        } else if (includeForm) {
            $overlayDialog.find(":input").filter("[type!='hidden']").first().trigger("focus");
        }
        setTimeout(function () {
            overlayInfo.otherCloseKey =  _checkSetting("closeKey", null);
        }, 300);
    });
    
    return overlayId;
    
    function _checkSetting(propName, defaultValue) {
        if (settings.hasOwnProperty(propName)) {
            return settings[propName];
        }
        return defaultValue;
    }
    
    function _setContent (name, content) {
        let $element = $("#" + _getId(name));
        if (!content) {
            $element.remove();
        } else if (content.jquery) {
            $element.empty().append(content);
        } else {
            $element.empty().html(content);
        }
    }
    
    function _startWaiting() {
        $overlayBlocker.find("[type='submit']").prop("disabled", true);
        $overlayBlocker.addClass("overlay-Waiting");
    }
    
    function _endWaiting() {
        $overlayBlocker.find("[type='submit']").prop("disabled", false);
        $overlayBlocker.removeClass("overlay-Waiting");
    }
    
    function _getDiv(name) {
        return "<div id='" + _getId(name) + "' class='" + _getClass(name) + "'></div>";
    }
    
    function _getId(name) {
        return overlayId + "_" + name;
    }
    
    function _getClass(suffix) {
        if ((settings.classes) && (settings.classes.hasOwnProperty(suffix))) {
            return settings.classes[suffix];
        }
        let prefix = "overlay-Component_";
        if (settings.classPrefix) {
            prefix = settings.classPrefix;
        }
        if ((settings.supplementaryClasses) && (settings.supplementaryClasses.hasOwnProperty(suffix))) {
            return prefix + suffix + " " + settings.supplementaryClasses[suffix];
        } else {
            return prefix + suffix;
        }
    }
};

Overlay.end = function (overlayId, callback) {
    if (overlayId.jquery) {
        overlayId = overlayId.data("overlayId");
    }
    if (!overlayId) {
        return;
    }
    var $overlayBlocker = $("#" + overlayId + "_blocker");
    var beforeEnd = $overlayBlocker.data("beforeEnd");
    if (beforeEnd) {
        var result = beforeEnd($overlayBlocker.children("div"));
        if (result === false) {
            return;
        }
    }
    _pop();
    $overlayBlocker.empty();
    var afterEnd = $overlayBlocker.data("afterEnd");
    $overlayBlocker.fadeOut(function() {
        $("#" + overlayId + "_blocker").remove();
        if ($("body").children("[data-overlay-role='blocker']").length === 0) {
            $("body").css('overflow','');
          }
        if (afterEnd) {
            afterEnd();
        }
        if (callback) {
            callback();
        }
    });
    
    function _pop() {
        for(var i = 0, len = Overlay.activeInfoArray.length; i < len; i++) {
            var overlayInfo = Overlay.activeInfoArray[i];
            if (overlayInfo.overlayId === overlayId) {
                Overlay.activeInfoArray.splice(i, 1);
                break;
            }
        }
        if (Overlay.activeInfoArray.length === 0) {
            Overlay.removeEscapeKeyHandler(document);
        }
    }
};